==> tmdb_api-1.2.2.tar.gz: CHANGELOG.md <==
## [1.2.1] - 17-6-2020
    bug fix 
* # 1.2.2

* # 1.2.1
    Bug fix by @Arley011 with PR #13

* # 1.2.0
  **There are some breaking changes**
  * All the exceptions now implements `TMDBException`
  * Throw `TMDBSocketException` if internet connection is not avaliable.
* # 1.1.0
    previous version was causing unwanted console logs so i removed it.
but you can still access those logs using **logConfig** parameter in `TMDB` class.

* # 1.0.0-stable
    Out of beta
* # 1.0.0-beta.1
    Updated ReadMe

* # 1.0.0-beta
    Almost all the features are added
    (*if any features are missing you can create a issue*)

    **There are some breaking changes to be noted**

     ## Avaliabe features

       v3( 🎊✨ Completed 🎉🎉)
        - [X] Auth
        - [X] Account
        - [X] Guest Sessions
        - [x] Movies
        - [x] Tv shows
        - [x] Tv Seasons
        - [x] Tv Episodes 
        - [X] People
        - [X] Credits
        - [X] Certification
        - [X] Changes
        - [X] Collections
        - [X] Find
        - [X] Genres
        - [X] Keywords
        - [X] Companies
        - [X] Trending
        - [X] Search
        - [X] Discover
        - [X] Networks
        - [X] Reviews
        - [X] Versions
        - [X] Lists
    
       v4(🎊✨ Completed 🎉🎉)
        - [X] Image URL Constructor
        - [X] auth
        - [X] account
        - [X] lists


    

* # 0.3.1-alpha
  support for v3 API

  added
    - [X] Discover
    - [X] Networks
    - [X] Reviews
    - [X] Versions
  
     Refer [README.md](https://github.com/Arunnaidu3470/tmdb_api/blob/master/README.md) for more info

* # Avaliable features (0.2.1-alpha)
  - [x] Trending
  - Updated README.md

* # Avaliable features (0.2.0-alpha)
  - [x] Movies
  - [x] Tv shows
  - [x] Tv Seasons
  - [x] Tv Episodes 
  - [X] People
  - [X] Credits
  - [X] Certification
  - [X] Changes
  - [X] Collections
  - [X] Find
  - [X] Genres
  - [X] Keywords
  - [X] Companies

==> tmdb_api-1.2.3.tar.gz: CHANGELOG.md <==
## 1.2.3
- Fixed append to response bug. [#16](https://github.com/RatakondalaArun/tmdb_api/issues/16)
  - Thanks to [@Viswanth1038](https://github.com/Viswanth1038) for contributing this fix.
  
## 1.2.2
bug fix 
## 1.2.1
- Bug fix by @Arley011 with PR #13

## 1.2.0
  **There are some breaking changes**
  - All the exceptions now implements `TMDBException`
  - Throw `TMDBSocketException` if internet connection is not avaliable.
## 1.1.0
    previous version was causing unwanted console logs so i removed it.
but you can still access those logs using **logConfig** parameter in `TMDB` class.

## 1.0.0-stable
    Out of beta
## 1.0.0-beta.1
    Updated ReadMe

## 1.0.0-beta
    Almost all the features are added
    (*if any features are missing you can create a issue*)

    **There are some breaking changes to be noted**

     ## Avaliabe features

       v3( 🎊✨ Completed 🎉🎉)
        - [X] Auth
        - [X] Account
        - [X] Guest Sessions
        - [x] Movies
        - [x] Tv shows
        - [x] Tv Seasons
        - [x] Tv Episodes 
        - [X] People
        - [X] Credits
        - [X] Certification
        - [X] Changes
        - [X] Collections
        - [X] Find
        - [X] Genres
        - [X] Keywords
        - [X] Companies
        - [X] Trending
        - [X] Search
        - [X] Discover
        - [X] Networks
        - [X] Reviews
        - [X] Versions
        - [X] Lists
    
       v4(🎊✨ Completed 🎉🎉)
        - [X] Image URL Constructor
        - [X] auth
        - [X] account
        - [X] lists


    

## 0.3.1-alpha
  support for v3 API

  added
    - [X] Discover
    - [X] Networks
    - [X] Reviews
    - [X] Versions
  
     Refer [README.md](https://github.com/Arunnaidu3470/tmdb_api/blob/master/README.md) for more info

## Avaliable features (0.2.1-alpha)
  - [x] Trending
  - Updated README.md

## Avaliable features (0.2.0-alpha)
  - [x] Movies
  - [x] Tv shows
  - [x] Tv Seasons
  - [x] Tv Episodes 
  - [X] People
  - [X] Credits
  - [X] Certification
  - [X] Changes
  - [X] Collections
  - [X] Find
  - [X] Genres
  - [X] Keywords
  - [X] Companies
